@@ -1,12 +1,13 @@
 #' Generate Adjacency Matrix
 #'
-#' Helper function that generates an adjacency matrix
+#' Helper function that generates an adjacency matrix.
 #'
 #' @param spatial_positions set of spatial positions
 #' @param sigma max distance between group points
 #' @return Adjacency Matrix
-#' @export
 generate_adjacency_matrix <- function(spatial_positions, sigma) {
+  colnames(spatial_positions) <- c("ponto", "x", "y", "z")
+
   lines <- nrow(spatial_positions)
 
   adjacency_matrix <- matrix(FALSE, nrow = lines, ncol = lines)
@@ -16,7 +17,8 @@ generate_adjacency_matrix <- function(spatial_positions, sigma) {
       if (i != j) {
         distance <- sqrt(
           (spatial_positions$x[i] - spatial_positions$x[j])^2 +
-            (spatial_positions$y[i] - spatial_positions$y[j])^2
+            (spatial_positions$y[i] - spatial_positions$y[j])^2 +
+            (spatial_positions$z[i] - spatial_positions$z[j])^2
         )
         if (distance <= sigma) {
           adjacency_matrix[i, j] <- TRUE
